@@ -4,26 +4,25 @@ var searchData=
   ['read_1',['read',['../classlibcamera_1_1File.html#acfe64877b7c056697bdeea56d553b383',1,'libcamera::File::read()'],['../classlibcamera_1_1ByteStreamBuffer.html#ad904b7ed94da3c8d266863a1ed2cf995',1,'libcamera::ByteStreamBuffer::read(T *t)'],['../classlibcamera_1_1ByteStreamBuffer.html#a8a614c18384f105e295724f9aef2a1ec',1,'libcamera::ByteStreamBuffer::read(const Span&lt; T &gt; &amp;data)'],['../classlibcamera_1_1ByteStreamBuffer.html#a5128ab4e3c75aa968dee6dd5ed0f2d94',1,'libcamera::ByteStreamBuffer::read(size_t count=1)']]],
   ['receive_2',['receive',['../classlibcamera_1_1IPCUnixSocket.html#a11995aca6423a568e6d1303dc80cd239',1,'libcamera::IPCUnixSocket']]],
   ['receiver_3',['receiver',['../classlibcamera_1_1Message.html#a033904a82d0de72889559b6aafeeaae8',1,'libcamera::Message']]],
-  ['rectangle_4',['Rectangle',['../classlibcamera_1_1Rectangle.html#adb78476ea887d264ceee7922bfa43c69',1,'libcamera::Rectangle::Rectangle()'],['../classlibcamera_1_1Rectangle.html#a59ccd67560f140e48bb70c4448cc1c74',1,'libcamera::Rectangle::Rectangle(int xpos, int ypos, const Size &amp;size)'],['../classlibcamera_1_1Rectangle.html#a94332066625a5986ed7a51256af75a88',1,'libcamera::Rectangle::Rectangle(int xpos, int ypos, unsigned int w, unsigned int h)'],['../classlibcamera_1_1Rectangle.html#a4a1c9f10ce8a2a86e2056a78dde3cd19',1,'libcamera::Rectangle::Rectangle(const Size &amp;size)']]],
+  ['rectangle_4',['rectangle',['../classlibcamera_1_1Rectangle.html#adb78476ea887d264ceee7922bfa43c69',1,'libcamera::Rectangle::Rectangle()'],['../classlibcamera_1_1Rectangle.html#a59ccd67560f140e48bb70c4448cc1c74',1,'libcamera::Rectangle::Rectangle(int xpos, int ypos, const Size &amp;size)'],['../classlibcamera_1_1Rectangle.html#a94332066625a5986ed7a51256af75a88',1,'libcamera::Rectangle::Rectangle(int xpos, int ypos, unsigned int w, unsigned int h)'],['../classlibcamera_1_1Rectangle.html#a4a1c9f10ce8a2a86e2056a78dde3cd19',1,'libcamera::Rectangle::Rectangle(const Size &amp;size)']]],
   ['registeralgorithm_5',['registerAlgorithm',['../classlibcamera_1_1ipa_1_1Module.html#a62af12d353cea10272b2feb34671ef18',1,'libcamera::ipa::Module']]],
   ['registercamera_6',['registerCamera',['../classlibcamera_1_1PipelineHandler.html#a97bc7a1ac8e7128d4b3dff91eb03f2a4',1,'libcamera::PipelineHandler']]],
-  ['registereventnotifier_7',['registerEventNotifier',['../classlibcamera_1_1EventDispatcher.html#a3c88ad0cc1eeb3bace6f78dd65256ef8',1,'libcamera::EventDispatcher::registerEventNotifier()'],['../classlibcamera_1_1EventDispatcherPoll.html#aebc4fda2b87d7ed67cbb19510d190cfc',1,'libcamera::EventDispatcherPoll::registerEventNotifier()']]],
+  ['registereventnotifier_7',['registereventnotifier',['../classlibcamera_1_1EventDispatcher.html#a3c88ad0cc1eeb3bace6f78dd65256ef8',1,'libcamera::EventDispatcher::registerEventNotifier()'],['../classlibcamera_1_1EventDispatcherPoll.html#aebc4fda2b87d7ed67cbb19510d190cfc',1,'libcamera::EventDispatcherPoll::registerEventNotifier()']]],
   ['registermessagetype_8',['registerMessageType',['../classlibcamera_1_1Message.html#ab05060113830c8501f0a0049084ad11b',1,'libcamera::Message']]],
   ['registerprocess_9',['registerProcess',['../classlibcamera_1_1ProcessManager.html#a3f30392724106a1a61f80f09a54c73cb',1,'libcamera::ProcessManager']]],
   ['registerrequest_10',['registerRequest',['../classlibcamera_1_1PipelineHandler.html#a9ca1e760238bd7cce8b78092333e2c6a',1,'libcamera::PipelineHandler']]],
-  ['registertimer_11',['registerTimer',['../classlibcamera_1_1EventDispatcher.html#aad6f0d92bd0745af50a165ec8cf58453',1,'libcamera::EventDispatcher::registerTimer()'],['../classlibcamera_1_1EventDispatcherPoll.html#a62b43090e99b13e883fb30c8c768d2d2',1,'libcamera::EventDispatcherPoll::registerTimer()']]],
+  ['registertimer_11',['registertimer',['../classlibcamera_1_1EventDispatcher.html#aad6f0d92bd0745af50a165ec8cf58453',1,'libcamera::EventDispatcher::registerTimer()'],['../classlibcamera_1_1EventDispatcherPoll.html#a62b43090e99b13e883fb30c8c768d2d2',1,'libcamera::EventDispatcherPoll::registerTimer()']]],
   ['release_12',['release',['../classlibcamera_1_1PipelineHandler.html#aead119b03920f468fa3bd091bfd65e5b',1,'libcamera::PipelineHandler::release()'],['../classlibcamera_1_1UniqueFD.html#aa5060be321f69a3c0282dad40bac88d6',1,'libcamera::UniqueFD::release()'],['../classlibcamera_1_1MediaDevice.html#a511ae507d3fffc097e938a7f55eb801c',1,'libcamera::MediaDevice::release()'],['../classlibcamera_1_1Camera.html#a5399b0249ee510f15f224e51a2e92c7b',1,'libcamera::Camera::release()'],['../classlibcamera_1_1Semaphore.html#a4dd1d0e84deb03a3a86c1116b09935ff',1,'libcamera::Semaphore::release()'],['../classlibcamera_1_1Fence.html#a6fcdbbc8bb00428300d8a803702d546d',1,'libcamera::Fence::release()']]],
   ['releasebuffers_13',['releaseBuffers',['../classlibcamera_1_1V4L2VideoDevice.html#a191619c152f764e03bc461611f3fcd35',1,'libcamera::V4L2VideoDevice']]],
   ['releasedevice_14',['releaseDevice',['../classlibcamera_1_1PipelineHandler.html#a53f4bee6b4c1f4b071b5e2f7584a93f8',1,'libcamera::PipelineHandler']]],
   ['releasefence_15',['releaseFence',['../classlibcamera_1_1FrameBuffer.html#a6312ef39ae7cf1d4f5c7b22d56e0e227',1,'libcamera::FrameBuffer']]],
   ['removedevice_16',['removeDevice',['../classlibcamera_1_1DeviceEnumerator.html#a3c539b6b75170fcf224ed5574c971842',1,'libcamera::DeviceEnumerator']]],
-  ['request_17',['Request',['../classlibcamera_1_1Request.html#adce12d1213e5d894a5697ddd4b94b672',1,'libcamera::Request']]],
-  ['request_18',['request',['../classlibcamera_1_1FrameBuffer.html#a4cd8c7f94d994ec9015a0e21720593c4',1,'libcamera::FrameBuffer']]],
-  ['reserve_19',['reserve',['../classlibcamera_1_1ControlValue.html#a60d6cdbb9c33d1c09204d35ae851d617',1,'libcamera::ControlValue']]],
-  ['reset_20',['reset',['../classlibcamera_1_1UniqueFD.html#af22d8122d42de7927dbedbdf730d04d0',1,'libcamera::UniqueFD::reset()'],['../classlibcamera_1_1Request_1_1Private.html#a5522c59f19f2dee9ac6d360f41ba1822',1,'libcamera::Request::Private::reset()'],['../classlibcamera_1_1DelayedControls.html#a7f1f0e7b61b8e4de431bb279296950dd',1,'libcamera::DelayedControls::reset()'],['../classlibcamera_1_1ControlSerializer.html#a6613ac42ffac5ee1c43d7fcfcc5d94a9',1,'libcamera::ControlSerializer::reset()']]],
-  ['resolution_21',['resolution',['../classlibcamera_1_1CameraSensor.html#a4f21b439f5fdb7d11927ddfe5554d571',1,'libcamera::CameraSensor']]],
-  ['resolvepath_22',['resolvePath',['../classlibcamera_1_1IPAProxy.html#aa298816d19d6455f64f3456ccaa70a98',1,'libcamera::IPAProxy']]],
-  ['reuse_23',['reuse',['../classlibcamera_1_1Request.html#aeb951e740b488f282292519625025491',1,'libcamera::Request']]],
-  ['reverse_24',['reverse',['../utils_8h.html#ad77ea11443473007cc0127e21a6a3e51',1,'libcamera::utils']]],
-  ['run_25',['run',['../classlibcamera_1_1Thread.html#a7e7d63b01477fa9987f5505f82f32913',1,'libcamera::Thread::run()'],['../classlibcamera_1_1ThreadMain.html#a06fd0d5ebb23cac7587793d2203b54ac',1,'libcamera::ThreadMain::run()']]]
+  ['request_17',['request',['../classlibcamera_1_1Request.html#adce12d1213e5d894a5697ddd4b94b672',1,'libcamera::Request::Request()'],['../classlibcamera_1_1FrameBuffer.html#a4cd8c7f94d994ec9015a0e21720593c4',1,'libcamera::FrameBuffer::request()']]],
+  ['reserve_18',['reserve',['../classlibcamera_1_1ControlValue.html#a60d6cdbb9c33d1c09204d35ae851d617',1,'libcamera::ControlValue']]],
+  ['reset_19',['reset',['../classlibcamera_1_1UniqueFD.html#af22d8122d42de7927dbedbdf730d04d0',1,'libcamera::UniqueFD::reset()'],['../classlibcamera_1_1Request_1_1Private.html#a5522c59f19f2dee9ac6d360f41ba1822',1,'libcamera::Request::Private::reset()'],['../classlibcamera_1_1DelayedControls.html#a7f1f0e7b61b8e4de431bb279296950dd',1,'libcamera::DelayedControls::reset()'],['../classlibcamera_1_1ControlSerializer.html#a6613ac42ffac5ee1c43d7fcfcc5d94a9',1,'libcamera::ControlSerializer::reset()']]],
+  ['resolution_20',['resolution',['../classlibcamera_1_1CameraSensor.html#a4f21b439f5fdb7d11927ddfe5554d571',1,'libcamera::CameraSensor']]],
+  ['resolvepath_21',['resolvePath',['../classlibcamera_1_1IPAProxy.html#aa298816d19d6455f64f3456ccaa70a98',1,'libcamera::IPAProxy']]],
+  ['reuse_22',['reuse',['../classlibcamera_1_1Request.html#aeb951e740b488f282292519625025491',1,'libcamera::Request']]],
+  ['reverse_23',['reverse',['../utils_8h.html#ad77ea11443473007cc0127e21a6a3e51',1,'libcamera::utils']]],
+  ['run_24',['run',['../classlibcamera_1_1Thread.html#a7e7d63b01477fa9987f5505f82f32913',1,'libcamera::Thread::run()'],['../classlibcamera_1_1ThreadMain.html#a06fd0d5ebb23cac7587793d2203b54ac',1,'libcamera::ThreadMain::run()']]]
 ];
