@@ -9,7 +9,7 @@ var searchData=
   ['pixelarrayactiveareas_6',['PixelArrayActiveAreas',['../namespacelibcamera_1_1properties.html#acec5675f79b6c456aca72c7532a263a4',1,'libcamera::properties']]],
   ['pixelarrayopticalblackrectangles_7',['PixelArrayOpticalBlackRectangles',['../namespacelibcamera_1_1properties.html#a1db1cc635572a20568410fa3a9a51660',1,'libcamera::properties']]],
   ['pixelarraysize_8',['PixelArraySize',['../namespacelibcamera_1_1properties.html#aac88aeb6478c1f8528cc08521486dae3',1,'libcamera::properties']]],
-  ['pixelformat_9',['pixelFormat',['../structlibcamera_1_1StreamConfiguration.html#ac1e89568d5c4a1fbed4157908a9af02e',1,'libcamera::StreamConfiguration::pixelFormat'],['../structlibcamera_1_1IPAStream.html#a5969f165122253154a8cb2b60f70e3a8',1,'libcamera::IPAStream::pixelFormat']]],
+  ['pixelformat_9',['pixelformat',['../structlibcamera_1_1StreamConfiguration.html#ac1e89568d5c4a1fbed4157908a9af02e',1,'libcamera::StreamConfiguration::pixelFormat'],['../structlibcamera_1_1IPAStream.html#a5969f165122253154a8cb2b60f70e3a8',1,'libcamera::IPAStream::pixelFormat']]],
   ['pixelrate_10',['pixelRate',['../structlibcamera_1_1IPACameraSensorInfo.html#af206d221ce7528fe6891967b2b85b7b6',1,'libcamera::IPACameraSensorInfo']]],
   ['pixelspergroup_11',['pixelsPerGroup',['../classlibcamera_1_1PixelFormatInfo.html#acd4b8bf93f17ceff24afc5e75613232c',1,'libcamera::PixelFormatInfo']]],
   ['planes_12',['planes',['../structlibcamera_1_1IPABuffer.html#a74dcffeed215ac7605e4856eec9856f6',1,'libcamera::IPABuffer::planes'],['../classlibcamera_1_1V4L2DeviceFormat.html#a8fbfab032fb2fdcc2112d3cbea4ef284',1,'libcamera::V4L2DeviceFormat::planes'],['../classlibcamera_1_1PixelFormatInfo.html#af570970ef29915513115cc68dba75a2a',1,'libcamera::PixelFormatInfo::planes']]],
